==> xmgfv1.9.1.tar.gz: xmgf/inc/XmgfGlobal.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 *
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

extern t_XmgfSets   gfSets;
extern t_LL         NameList, ColorNameList, All_Polys;
extern Window       w_Plan, w_Side, w_Frnt, w_Orth, w_Left, w_Right;
extern double       Scale_factor;
extern int          ScaleNumber, defScale_factor, PointType;
extern int          Theta, Phi, Gamma, Ox, Oy, Oz, defscal, Midx, Midy;
extern int          defOX, defOY, defOZ, defTheta, defPhi, defGamma;
extern int          WindowOpen, LoadOpen, SaveOpen, AppendOpen, viewtype,
                    DoPoly;
extern XtAppContext appContext;
extern char        *CurrentString;

extern double       CentroidX, CentroidY, CentroidZ;
extern double       CentreX, CentreY, CentreZ;
extern double       ImageMinX, ImageMaxX, ImageMinY, ImageMaxY;
extern double       LocObjX, LocObjY, LocObjZ;
extern double       LocRotX, LocRotY, LocRotZ;
extern double       RocCenX, RocCenY, RocCenZ;
extern double       LocalScale;
extern double       LocScaleX,LocScaleY,LocScaleZ;
extern double       ScaleCenX,ScaleCenY,ScaleCenZ;
extern t_LL         CurrentFileList;
extern t_LL    	    HighLightedPoly;

extern char        *PGMDIR;
extern char        *PGMFIL;
extern char        *XBMDIR;
extern char        *XBMFIL;
extern char        *PBMDIR;
extern char        *PBMFIL;
extern char        *PPMDIR;
extern char        *PPMFIL;
extern char        *GIFDIR;
extern char        *GIFFIL;
extern char        *RASDIR;
extern char        *RASFIL;
extern char        *GFDIR;
extern char        *GFFIL;
extern char        *IMGDIR;
extern char        *IMGFIL;
extern char        *POSTDIR;
extern char        *POSTFIL;
extern char        *EPSDIR;
extern char        *EPSFIL;
extern char        *FIGDIR;
extern char        *FIGFIL;
extern char        *PARMDIR;
extern char        *PARMFIL;
extern char        *RAYDIR;
extern char        *RAYFIL;
extern char        *IMPORTDIR;
extern char        *IMPORTFIL;
extern char        *CMAPDIR;
extern char        *CMAPFIL;
extern char        *MIFDIR;
extern char        *MIFFIL;
extern char        *ANIMDIR;
extern char        *ANIMFIL;
extern char        *CurrentFile;

==> xmgfv2.4.tar.gz: xmgf/inc/XmgfGlobal.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 *
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

extern t_XmgfSets   gfSets;
extern t_LL         NameList, ColorNameList, All_Polys;
extern Window       w_Plan, w_Side, w_Frnt, w_Orth, w_Left, w_Right;
extern double       Scale_factor;
extern int          ScaleNumber, defScale_factor, PointType;
extern int          Theta, Phi, Gamma, Ox, Oy, Oz, defscal, Midx, Midy;
extern int          defOX, defOY, defOZ, defTheta, defPhi, defGamma;
extern int          WindowOpen, LoadOpen, SaveOpen, AppendOpen, viewtype,
                    DoPoly;
extern XtAppContext appContext;
extern char        *CurrentString;

extern double       CentroidX, CentroidY, CentroidZ;
extern double       MinXDisp,MinYDisp,MinZDisp;
extern double       MaxXDisp,MaxYDisp,MaxZDisp;
extern double       CentreX, CentreY, CentreZ;
extern double       ImageMinX, ImageMaxX, ImageMinY, ImageMaxY;
extern double       LocObjX, LocObjY, LocObjZ;
extern double       LocRotX, LocRotY, LocRotZ;
extern double       RocCenX, RocCenY, RocCenZ;
extern double       LocalScale;
extern double       LocScaleX,LocScaleY,LocScaleZ;
extern double       ScaleCenX,ScaleCenY,ScaleCenZ;
extern t_LL         CurrentFileList;
extern t_LL    	    HighLightedPoly;

extern char        *PGMDIR;
extern char        *PGMFIL;
extern char        *XBMDIR;
extern char        *XBMFIL;
extern char        *PBMDIR;
extern char        *PBMFIL;
extern char        *PPMDIR;
extern char        *PPMFIL;
extern char        *GIFDIR;
extern char        *GIFFIL;
extern char        *RASDIR;
extern char        *RASFIL;
extern char        *GFDIR;
extern char        *GFFIL;
extern char        *IMGDIR;
extern char        *IMGFIL;
extern char        *POSTDIR;
extern char        *POSTFIL;
extern char        *EPSDIR;
extern char        *EPSFIL;
extern char        *FIGDIR;
extern char        *FIGFIL;
extern char        *PARMDIR;
extern char        *PARMFIL;
extern char        *RAYDIR;
extern char        *RAYFIL;
extern char        *IMPORTDIR;
extern char        *IMPORTFIL;
extern char        *CMAPDIR;
extern char        *CMAPFIL;
extern char        *MIFDIR;
extern char        *MIFFIL;
extern char        *ANIMDIR;
extern char        *ANIMFIL;
extern char        *PCXDIR;
extern char        *PCXFIL;
extern char        *PICTDIR;
extern char        *PICTFIL;
extern char        *CurrentFile;
